# -*- coding: utf-8 -*-

project = 'astropy-helpers'
copyright = '2014, The Astropy Developers'
author = 'The Astropy Developers'

# We need to get the version number from the package
import sys  # noqa
sys.path.insert(0, '..')
import astropy_helpers  # noqa
version = astropy_helpers.__version__
release = astropy_helpers.__version__

extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.doctest',
    'sphinx.ext.intersphinx',
    'numpydoc',
    'sphinx_automodapi.automodapi'
]

numpydoc_show_class_members = False

intersphinx_mapping = {'https://docs.python.org/': None}

# The suffix(es) of source filenames.
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = 'bootstrap-astropy'

html_theme_options = {
    'logotext1': 'astropy',  # white,  semi-bold
    'logotext2': '-helpers',  # orange, light
    'logotext3': ':docs'   # white,  light
    }



# Autogenerated by Astropy-affiliated package gwcs's setup.py on 2019-07-26 21:18:07 UTC
from __future__ import unicode_literals
import datetime

version = "0.11.0"
githash = "354da7cdafcfe7bcf7df5dc2682ff1f39541ec6c"


major = 0
minor = 11
bugfix = 0

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 7, 26, 21, 18, 7)
debug = False

astropy_helpers_version = "3.2.1"



import os

# this contains imports plugins that configure py.test for astropy tests.
# by importing them here in conftest.py they are discoverable by py.test
# no matter how it is invoked within the source tree.

from astropy.tests.helper import enable_deprecations_as_exceptions
from astropy.tests.plugins.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS

# Uncomment the following line to treat all DeprecationWarnings as
# exceptions
#enable_deprecations_as_exceptions()

try:
    PYTEST_HEADER_MODULES['Astropy'] = 'astropy'
    PYTEST_HEADER_MODULES['asdf'] = 'asdf'
    del PYTEST_HEADER_MODULES['h5py']
except (NameError, KeyError):
    pass

# This is to figure out the affiliated package version, rather than
# using Astropy's
from . import version

try:
    packagename = os.path.basename(os.path.dirname(__file__))
    TESTED_VERSIONS[packagename] = version.version
except NameError:   # Needed to support Astropy <= 1.0.0
    pass

pytest_plugins = [
    'asdf.tests.schema_tester'
]
